@@ -19,4 +19,4 @@ def get_error_response(
         details=details,
         status_code=status_code,
         api_docs=NWON_DJANGO_SETTINGS.api_docs_url,
-    ).dict()
+    ).model_dump()
