@@ -1,3 +1,5 @@
+from typing import Any
+
 from django.db import models
 
 
@@ -7,11 +9,22 @@ class LowercaseEmailField(models.EmailField):
     """
 
     def to_python(self, value):
-        """
-        Convert email to lowercase.
-        """
         value = super(LowercaseEmailField, self).to_python(value)
-        # Value can be None so check that it's a string before lowercasing.
+
+        if isinstance(value, str):
+            return value.lower()
+
+        return value
+
+    def from_db_value(self, value, expression, connection):
+        if isinstance(value, str):
+            return value.lower()
+
+        return value
+
+    def get_prep_value(self, value: Any) -> Any:
+        value = super(LowercaseEmailField, self).to_python(value)
+
         if isinstance(value, str):
             return value.lower()
 
