@@ -14,7 +14,7 @@ def dump_fixtures(fixture_files: List[Fixture]):
         sys.stdout = open(
             fixture.path, "w", encoding=NWON_DJANGO_SETTINGS.file_encoding
         )
-        call_command("dumpdata", fixture.model_name)
+        call_command("dumpdata", fixture.name_model)
 
     sys.stdout = sys_out
 
