@@ -1,7 +1,14 @@
 from typing import List, Optional
 
-import humps
-from pydantic import BaseModel, Field
+from pydantic import AliasGenerator, BaseModel, ConfigDict, Field
+from pydantic.alias_generators import to_camel
+
+
+class NWONDjangoTestSettings(BaseModel):
+    keys_to_skip_on_api_test: List[str] = Field(
+        default=[],
+        description="On some API test helper we check the returned objects against the initial parameters. During this check the given keys are skipped",
+    )
 
 
 class NWONDjangoSettings(BaseModel):
@@ -27,11 +34,6 @@ class NWONDjangoSettings(BaseModel):
         description="Default File encoding used for all file operations",
     )
 
-    keys_to_skip_on_api_test: List[str] = Field(
-        default=[],
-        description="On some API test helper we check the returned objects against the initial parameters. During this check the given keys are skipped",
-    )
-
     application_name: Optional[str] = Field(
         default=None,
         description="Application name that is used whenever needed",
@@ -42,16 +44,16 @@ class NWONDjangoSettings(BaseModel):
         description="Url to the API docs. Used for error handler",
     )
 
-    # Basically the same config as PydanticBaseDjango but we can't import because of a circular import problem
-    class Config:
-        # no additional properties
-        extra = "forbid"
+    tests: Optional[NWONDjangoTestSettings] = Field(
+        default=None,
+        description="Test related configurations",
+    )
 
-        # Allow initialization via attribute names and aliases
-        allow_population_by_field_name = True
-
-        # auto generate camelized aliases
-        alias_generator = humps.camelize
+    model_config = ConfigDict(
+        alias_generator=AliasGenerator(validation_alias=to_camel),
+        populate_by_name=True,
+        extra="forbid",
+    )
 
 
-__all__ = ["NWONDjangoSettings"]
+__all__ = ["NWONDjangoSettings", "NWONDjangoTestSettings"]
