@@ -21,11 +21,11 @@ def check_number_of_created_tasks(celery_folder: CeleryFolder, expected_number:
     if count_messages(celery_folder) != expected_number:
         LOGGER.debug(
             "Expected "
-            + expected_number.__str__()
+            + str(expected_number)
             + " celery tasks. Found "
-            + count_messages(celery_folder).__str__()
+            + str(count_messages(celery_folder))
             + "\n\n Messages\n"
-            + celery_messages_information(celery_folder).__str__()
+            + str(celery_messages_information(celery_folder))
         )
 
     assert count_messages(celery_folder) == expected_number
@@ -75,7 +75,7 @@ def check_latest_task(
 
 def __log_information(celery_folder: CeleryFolder):
     information = enqueued_tasks_and_messages(celery_folder)
-    LOGGER.debug("Currently scheduled tasks: %s", information.__str__())
+    LOGGER.debug("Currently scheduled tasks: %s", str(information))
 
 
 __all__ = [
