@@ -1,3 +1,4 @@
+from nwon_django_toolbox.typings.allowed_update import AllowedUpdate
 from nwon_django_toolbox.typings.celery import CeleryFolder, CeleryReturn
 from nwon_django_toolbox.typings.django_ready_enum import DjangoReadyEnum
 from nwon_django_toolbox.typings.error_response import ErrorResponse
@@ -31,4 +32,5 @@ __all__ = [
     "PermissionConfiguration",
     "PermissionConfigurationForGroup",
     "PermissionPrefix",
+    "AllowedUpdate",
 ]
