@@ -1,7 +1,7 @@
 from typing import Callable, Optional
 
 from django.db.models import Model
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 LoginFunction = Callable[[Model, str], str]
 
@@ -19,5 +19,4 @@ class PermissionTestExpectation(BaseModel):
     put_status_code: Optional[int] = None
     delete_status_code: Optional[int] = None
 
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
