@@ -8,14 +8,20 @@ from nwon_django_toolbox.settings import NWON_DJANGO_SETTINGS
 from nwon_django_toolbox.url_helper.url_helper import base_name_from_model
 
 
-def formatted_django_admin_link(model: Model, application: str = "tamoc") -> str:
+def formatted_django_admin_link(
+    model: Model, application: str = "nwon", link_text: Optional[str] = None
+) -> str:
     if application is None:
         raise Exception(
             "In order to use django_admin_link_for_model you need to set application_name in the NWON_DJANGO settings"
         )
 
     url = django_admin_link_for_model(model, application)
-    return format_html("<a href='{url}'>{text}</a>", url=url, text=model.__str__())
+    return format_html(
+        "<a href='{url}'>{text}</a>",
+        url=url,
+        text=link_text if link_text else model.__str__(),
+    )
 
 
 def django_admin_link_for_model(
